
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.024.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Be like SHLOMIF / Shlomi Fish.",
  "dist_author" => [
    "Shlomi Fish <shlomif\@cpan.org>"
  ],
  "dist_name" => "Task-BeLike-SHLOMIF",
  "dist_version" => "0.0.9",
  "license" => "mit",
  "module_name" => "Task::BeLike::SHLOMIF",
  "recursive_test_files" => 1,
  "requires" => {
    "App::CSV2Chart" => 0,
    "App::Countdown" => 0,
    "App::Deps::Verify" => 0,
    "App::Docmake" => 0,
    "App::Du::Analyze" => 0,
    "App::Gezer" => 0,
    "App::Git::Info" => 0,
    "App::Nopaste" => 0,
    "App::Notifier::Client" => 0,
    "App::Notifier::Service" => 0,
    "App::Sky" => 0,
    "App::Tac_n" => 0,
    "App::Timestamper" => 0,
    "App::Timestamper::Format" => 0,
    "App::Timestamper::WithElapsed" => 0,
    "App::gimpgitbuild" => 0,
    "App::intrunningsum" => 0,
    "App::intsum" => 0,
    "App::prefixintsumcol" => 0,
    "App::rshasum" => 0,
    "App::stopw" => 0,
    "App::xspf2m3u" => 0,
    "Bit::Vector" => 0,
    "Carp::Always" => 0,
    "Devel::LineTrace" => 0,
    "Devel::Trace" => 0,
    "Devel::TraceUse" => 0,
    "Devel::TraceVars" => 0,
    "Dist::Zilla::Plugin::Keywords" => 0,
    "Dist::Zilla::PluginBundle::SHLOMIF" => 0,
    "Docker::CLI::Wrapper" => 0,
    "File::Dir::Dumper" => 0,
    "GD" => 0,
    "HTML::Links::Localize" => 0,
    "Image::Size" => 0,
    "Math::Random::MT" => 0,
    "Module::Format" => 0,
    "Module::Format::AsHTML" => 0,
    "Perl::Tidy" => 0,
    "Pod::Coverage::TrustPod" => 0,
    "Pod::Xhtml" => 0,
    "SQ" => 0,
    "Task::FreecellSolver::Testing" => 0,
    "Task::FreecellSolver::Testing::MultiConfig" => 0,
    "Task::Sites::ShlomiFish" => 0,
    "Term::ReadLine::Gnu" => 0,
    "Test::File::IsSorted" => 0,
    "Test::Pod" => 0,
    "Test::Some" => 0,
    "Tree::AVL" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => "0.88",
    "perl" => "5.006"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::More" => "0.88",
  "perl" => "5.006"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
